@@ -1,12 +1,17 @@
 # -*- coding: utf-8 -*-
 import contextlib
+import django
 from django.core.exceptions import PermissionDenied
 from django.contrib.auth.models import update_last_login
 from django.contrib.auth.signals import user_logged_in
 from django.contrib.auth import login, load_backend, BACKEND_SESSION_KEY
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
-from django.utils.http import is_safe_url
+
+if django.VERSION >= (3, 0):
+    from django.utils.http import url_has_allowed_host_and_scheme
+else:
+    from django.utils.http import is_safe_url as url_has_allowed_host_and_scheme
 
 from compat import get_user_model, import_string
 from compat import resolve_url
@@ -65,7 +70,11 @@ def release_hijack(request):
         request.session.pop('is_hijacked_user', None)
         request.session.pop('display_hijack_warning', None)
     request.session.modified = True
-    hijack_ended.send(sender=None, hijacker_id=hijacker.pk, hijacked_id=hijacked.pk, request=request)
+    hijack_ended.send(
+            sender=None, request=request,
+            hijacker=hijacker, hijacked=hijacked,
+            # send IDs for backward compatibility
+            hijacker_id=hijacker.pk, hijacked_id=hijacked.pk)
     return redirect_to_next(request, default_url=hijack_settings.HIJACK_LOGOUT_REDIRECT_URL)
 
 
@@ -127,7 +136,11 @@ def login_user(request, hijacked):
         # Actually log user in
         login(request, hijacked)
 
-    hijack_started.send(sender=None, hijacker_id=hijacker.pk, hijacked_id=hijacked.pk, request=request)  # Send official, documented signal
+    hijack_started.send(
+            sender=None, request=request,
+            hijacker=hijacker, hijacked=hijacked,
+            # send IDs for backward compatibility
+            hijacker_id=hijacker.pk, hijacked_id=hijacked.pk)
     request.session['hijack_history'] = hijack_history
     request.session['is_hijacked_user'] = True
     request.session['display_hijack_warning'] = True
@@ -137,6 +150,10 @@ def login_user(request, hijacked):
 
 def redirect_to_next(request, default_url=hijack_settings.HIJACK_LOGIN_REDIRECT_URL):
     redirect_to = request.GET.get('next', '')
-    if not is_safe_url(redirect_to):
+    # is_safe_url's allowed_hosts keyword was added in Django 1.11, and became required in 2.1:
+    is_safe_url_kwargs = {}
+    if django.VERSION >= (1, 11):
+        is_safe_url_kwargs['allowed_hosts'] = {request.get_host()}
+    if not url_has_allowed_host_and_scheme(redirect_to, **is_safe_url_kwargs):
         redirect_to = default_url
     return HttpResponseRedirect(resolve_url(redirect_to))
