@@ -317,11 +317,15 @@ class HijackTests(BaseHijackTests):
     def test_signals(self):
         received_signals = []
 
-        def hijack_started_receiver(sender, hijacker_id, hijacked_id, request, **kwargs):
+        def hijack_started_receiver(sender, hijacker_id, hijacked_id, request, hijacker, hijacked, **kwargs):
+            self.assertEqual(hijacker_id, hijacker.id)
+            self.assertEqual(hijacked_id, hijacked.id)
             received_signals.append('hijack_started_%d_%d' % (hijacker_id, hijacked_id))
         hijack_started.connect(hijack_started_receiver)
 
-        def hijack_ended_receiver(sender, hijacker_id, hijacked_id, request, **kwargs):
+        def hijack_ended_receiver(sender, hijacker_id, hijacked_id, request, hijacker, hijacked, **kwargs):
+            self.assertEqual(hijacker_id, hijacker.id)
+            self.assertEqual(hijacked_id, hijacked.id)
             received_signals.append('hijack_ended_%d_%d' % (hijacker_id, hijacked_id))
         hijack_ended.connect(hijack_ended_receiver)
 
@@ -342,7 +346,7 @@ class HijackTests(BaseHijackTests):
             self._release_hijack()
 
     def test_middleware_without_remote_user(self):
-        middleware = HijackRemoteUserMiddleware()
+        middleware = HijackRemoteUserMiddleware(lambda r: None)
         factory = RequestFactory()
         request = factory.get('/')
         request.session = {}
@@ -352,7 +356,7 @@ class HijackTests(BaseHijackTests):
         self.assertEqual(request.META.get('REMOTE_USER'), None)
 
     def test_middleware_with_remote_user(self):
-        middleware = HijackRemoteUserMiddleware()
+        middleware = HijackRemoteUserMiddleware(lambda r: None)
         factory = RequestFactory()
         request = factory.get('/')
         request.session = {'is_hijacked_user': True}
